smoosh.experimental

Experiment with ways to break down a 'merge' operation into parts that may be optimized.

Experiment with ways to break down a 'merge' operation into parts that may be
optimized.
raw docstring

experimental-mergeclj

(experimental-merge m1 m2)

See clojure.core/merge. Implemented with best benchmarked variants of set-ops, select-keys, and merge.

See `clojure.core/merge`. Implemented with best benchmarked variants of
`set-ops`, `select-keys`, and `merge`.
sourceraw docstring

experimental-merge-withclj

(experimental-merge-with f m1 m2)

See clojure.core/merge-with. Implemented with best benchmarked variants of set-ops, select-keys, merge, and merge-with.

See `clojure.core/merge-with`. Implemented with best benchmarked variants of
`set-ops`, `select-keys`, `merge`, and `merge-with`.
sourceraw docstring

faster?-mergeclj

source

faster?-merge-withclj

source

naive-mergeclj

(naive-merge m1 m2)

See clojure.core/merge. Not intended to be faster, merely demonstrate the algorithm.

See `clojure.core/merge`. Not intended to be faster, merely demonstrate the
algorithm.
sourceraw docstring

naive-merge-withclj

(naive-merge-with f m1 m2)

See clojure.core/merge-with. Not intended to be faster, merely demonstrate the algorithm.

See `clojure.core/merge-with`. Not intended to be faster, merely demonstrate
the algorithm.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries