Exploring different implementations of merge.
Note:
Exploring different implementations of `merge`. Note: 1. Argument types are not checked to be valid arraymaps/hashmaps. 2. Metadata is not preserved. 3. Map type (i.e., sorted) is not guaranteed to be preserved.
(deep-merge-CLJ-1468 & maps)Like merge, but merges maps recursively.
Like merge, but merges maps recursively. Source: https://clojure.atlassian.net/browse/CLJ-1468
(merge-merge m1 m2)Given hashmaps m1 and m1, returns a new hashmap merged exactly two
'levels' deep. Top-level keys must be associated to hashmaps that themselves
may be merge-ed. Does not check args for nil.
Given hashmaps `m1` and `m1`, returns a new hashmap merged exactly two 'levels' deep. Top-level keys *must* be associated to hashmaps that themselves may be `merge`-ed. Does not check args for `nil`.
(merge-merge-transient m1 m2)Given hashmaps m1 and m1, returns a new hashmap merged at most two
'levels' deep. Does not check args for nil.
Given hashmaps `m1` and `m1`, returns a new hashmap merged at most two 'levels' deep. Does not check args for `nil`.
(switched-reduce-kv-merge m1 m2)Switches tactics based upon input size.
Switches tactics based upon input size.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |