smoosh.set-operation-variants


droit-set-opsclj

(droit-set-ops left right)

Uses github:droitfintech's fset faster set implementations.

Uses github:droitfintech's `fset` faster set implementations.
sourceraw docstring

faster?-set-ops-1clj

(faster?-set-ops-1 left right)

Given sets left and right, returns a hashmap of intersection, difference-left and difference-right. Implementation intends to be faster by virtue of only walking the smaller set once.

Given sets `left` and `right`, returns a hashmap of intersection,
difference-left and difference-right. Implementation intends to be faster by
virtue of only walking the smaller set once.
sourceraw docstring

faster?-set-ops-2clj

(faster?-set-ops-2 left right)

Given sets left and right, returns a hashmap of the union, interesction, left difference, and right difference. Attempts to be faster by walking only the smaller set once. This implementation is the base case, not using transients. See also [[faster?-set-ops3]] for a variant that uses transients.

Given sets `left` and `right`, returns a hashmap of the union, interesction,
left difference, and right difference. Attempts to be faster by walking only
the smaller set once. This implementation is the base case, not using
transients. See also [[faster?-set-ops3]] for a variant that uses transients.
sourceraw docstring

faster?-set-ops-3clj

(faster?-set-ops-3 left right)

See [[faster?-set-ops2]].

See [[faster?-set-ops2]].
sourceraw docstring

faster?-set-ops-4clj

(faster?-set-ops-4 left right)
See [[faster?-set-ops-2]] and [[faster?-set-ops-3]].
sourceraw docstring

set-opsclj

(set-ops left right)

Given sets left and right, returns a hashmap of intersection, difference left\2, and difference right\left.

Given sets `left` and `right`, returns a hashmap of intersection, difference
`left\2`, and difference `right\left`.
sourceraw docstring

update-transientclj

(update-transient m k f)
(update-transient m k f x)
(update-transient m k f x y)
(update-transient m k f x y z)

Like update, but works on a transient hashmap.

Like `update`, but works on a transient hashmap.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries