Experiment with ways to break down a 'merge' operation into parts that may be optimized.
Experiment with ways to break down a 'merge' operation into parts that may be optimized.
(experimental-merge m1 m2)See clojure.core/merge. Implemented with best benchmarked variants of
set-ops, select-keys, and merge.
See `clojure.core/merge`. Implemented with best benchmarked variants of `set-ops`, `select-keys`, and `merge`.
(experimental-merge-with f m1 m2)See clojure.core/merge-with. Implemented with best benchmarked variants of
set-ops, select-keys, merge, and merge-with.
See `clojure.core/merge-with`. Implemented with best benchmarked variants of `set-ops`, `select-keys`, `merge`, and `merge-with`.
(naive-merge m1 m2)See clojure.core/merge. Not intended to be faster, merely demonstrate the
algorithm.
See `clojure.core/merge`. Not intended to be faster, merely demonstrate the algorithm.
(naive-merge-with f m1 m2)See clojure.core/merge-with. Not intended to be faster, merely demonstrate
the algorithm.
See `clojure.core/merge-with`. Not intended to be faster, merely demonstrate the algorithm.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |